==> haskell-skylighting-0.7.7-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-skylighting.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: skylighting
version: 0.7.7
id: skylighting-0.7.7-JV1I36D0zn17SM2IUs6tcT
key: skylighting-0.7.7-JV1I36D0zn17SM2IUs6tcT
license: GPL-2.0-only
copyright: (C) 2016 John MacFarlane
maintainer: jgm@berkeley.edu
author: John MacFarlane
homepage: https://github.com/jgm/skylighting
synopsis: syntax highlighting library
description:
    Skylighting is a syntax highlighting library with
    support for over one hundred languages.  It derives
    its tokenizers from XML syntax definitions used
    by KDE'\''s KSyntaxHighlighting framework, so any
    syntax supported by that framework can be added.
    An optional command-line program is provided.
    Skylighting is intended to be the successor to
    highlighting-kate.
    This package provides generated syntax modules
    based on the KDE XML definitions provided by the
    @skylighting-core@ package. As a result this
    package is licensed under the GPL.
category: Text
abi: c901d6fbc42d0e73734765ad67723add
exposed: True
exposed-modules:
    Skylighting,
    Skylighting.Core from skylighting-core-0.7.7-4fEAKVDBpx26AsLTtw5o3K:Skylighting.Core,
    Skylighting.Format.ANSI from skylighting-core-0.7.7-4fEAKVDBpx26AsLTtw5o3K:Skylighting.Format.ANSI,
    Skylighting.Format.HTML from skylighting-core-0.7.7-4fEAKVDBpx26AsLTtw5o3K:Skylighting.Format.HTML,
    Skylighting.Format.LaTeX from skylighting-core-0.7.7-4fEAKVDBpx26AsLTtw5o3K:Skylighting.Format.LaTeX,
    Skylighting.Parser from skylighting-core-0.7.7-4fEAKVDBpx26AsLTtw5o3K:Skylighting.Parser,
    Skylighting.Regex from skylighting-core-0.7.7-4fEAKVDBpx26AsLTtw5o3K:Skylighting.Regex,
    Skylighting.Styles from skylighting-core-0.7.7-4fEAKVDBpx26AsLTtw5o3K:Skylighting.Styles,
    Skylighting.Syntax,
    Skylighting.Tokenizer from skylighting-core-0.7.7-4fEAKVDBpx26AsLTtw5o3K:Skylighting.Tokenizer,
    Skylighting.Types from skylighting-core-0.7.7-4fEAKVDBpx26AsLTtw5o3K:Skylighting.Types
hidden-modules: Skylighting.Syntax.Abc
                Skylighting.Syntax.Actionscript Skylighting.Syntax.Ada
                Skylighting.Syntax.Agda Skylighting.Syntax.Alert
                Skylighting.Syntax.AlertIndent Skylighting.Syntax.Apache
                Skylighting.Syntax.Asn1 Skylighting.Syntax.Asp
                Skylighting.Syntax.Ats Skylighting.Syntax.Awk
                Skylighting.Syntax.Bash Skylighting.Syntax.Bibtex
                Skylighting.Syntax.Boo Skylighting.Syntax.C
                Skylighting.Syntax.Changelog Skylighting.Syntax.Clojure
                Skylighting.Syntax.Cmake Skylighting.Syntax.Coffee
                Skylighting.Syntax.Coldfusion Skylighting.Syntax.Commonlisp
                Skylighting.Syntax.Cpp Skylighting.Syntax.Cs Skylighting.Syntax.Css
                Skylighting.Syntax.Curry Skylighting.Syntax.D
                Skylighting.Syntax.Default Skylighting.Syntax.Diff
                Skylighting.Syntax.Djangotemplate Skylighting.Syntax.Dockerfile
                Skylighting.Syntax.Dot Skylighting.Syntax.Doxygen
                Skylighting.Syntax.Doxygenlua Skylighting.Syntax.Dtd
                Skylighting.Syntax.Eiffel Skylighting.Syntax.Elixir
                Skylighting.Syntax.Email Skylighting.Syntax.Erlang
                Skylighting.Syntax.Fasm Skylighting.Syntax.Fortran
                Skylighting.Syntax.Fsharp Skylighting.Syntax.Gcc
                Skylighting.Syntax.Glsl Skylighting.Syntax.Gnuassembler
                Skylighting.Syntax.Go Skylighting.Syntax.Hamlet
                Skylighting.Syntax.Haskell Skylighting.Syntax.Haxe
                Skylighting.Syntax.Html Skylighting.Syntax.Idris
                Skylighting.Syntax.Ini Skylighting.Syntax.Isocpp
                Skylighting.Syntax.J Skylighting.Syntax.Java
                Skylighting.Syntax.Javadoc Skylighting.Syntax.Javascript
                Skylighting.Syntax.Json Skylighting.Syntax.Jsp
                Skylighting.Syntax.Julia Skylighting.Syntax.Kotlin
                Skylighting.Syntax.Latex Skylighting.Syntax.Lex
                Skylighting.Syntax.Lilypond Skylighting.Syntax.LiterateCurry
                Skylighting.Syntax.LiterateHaskell Skylighting.Syntax.Llvm
                Skylighting.Syntax.Lua Skylighting.Syntax.M4
                Skylighting.Syntax.Makefile Skylighting.Syntax.Mandoc
                Skylighting.Syntax.Markdown Skylighting.Syntax.Mathematica
                Skylighting.Syntax.Matlab Skylighting.Syntax.Maxima
                Skylighting.Syntax.Mediawiki Skylighting.Syntax.Metafont
                Skylighting.Syntax.Mips Skylighting.Syntax.Modelines
                Skylighting.Syntax.Modula2 Skylighting.Syntax.Modula3
                Skylighting.Syntax.Monobasic Skylighting.Syntax.Nasm
                Skylighting.Syntax.Noweb Skylighting.Syntax.Objectivec
                Skylighting.Syntax.Objectivecpp Skylighting.Syntax.Ocaml
                Skylighting.Syntax.Octave Skylighting.Syntax.Opencl
                Skylighting.Syntax.Pascal Skylighting.Syntax.Perl
                Skylighting.Syntax.Php Skylighting.Syntax.Pike
                Skylighting.Syntax.Postscript Skylighting.Syntax.Povray
                Skylighting.Syntax.Powershell Skylighting.Syntax.Prolog
                Skylighting.Syntax.Protobuf Skylighting.Syntax.Pure
                Skylighting.Syntax.Purebasic Skylighting.Syntax.Python
                Skylighting.Syntax.R Skylighting.Syntax.Relaxng
                Skylighting.Syntax.Relaxngcompact Skylighting.Syntax.Rest
                Skylighting.Syntax.Rhtml Skylighting.Syntax.Roff
                Skylighting.Syntax.Ruby Skylighting.Syntax.Rust
                Skylighting.Syntax.Scala Skylighting.Syntax.Scheme
                Skylighting.Syntax.Sci Skylighting.Syntax.Sed
                Skylighting.Syntax.Sgml Skylighting.Syntax.Sml
                Skylighting.Syntax.SqlMysql Skylighting.Syntax.SqlPostgresql
                Skylighting.Syntax.Sql Skylighting.Syntax.Tcl
                Skylighting.Syntax.Tcsh Skylighting.Syntax.Texinfo
                Skylighting.Syntax.Typescript Skylighting.Syntax.Verilog
                Skylighting.Syntax.Vhdl Skylighting.Syntax.Xml
                Skylighting.Syntax.Xorg Skylighting.Syntax.Xslt
                Skylighting.Syntax.Xul Skylighting.Syntax.Yacc
                Skylighting.Syntax.Yaml Skylighting.Syntax.Zsh
import-dirs: /usr/lib/ghc-8.6.4/site-local/skylighting-0.7.7
library-dirs: /usr/lib/ghc-8.6.4/site-local/skylighting-0.7.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/skylighting-0.7.7
hs-libraries: HSskylighting-0.7.7-JV1I36D0zn17SM2IUs6tcT
depends:
    aeson-1.4.2.0-DX8Ttq0Dq5cG6DT1joU4wl
    ansi-terminal-0.8.2-8WQDEUM7Kz3DSmwgHomKFP
    attoparsec-0.13.2.2-6cOh3sci63HJyadcbPhvpT base-4.12.0.0
    base64-bytestring-1.0.0.2-EJ1mkGsqs004EmS9lh2uZC binary-0.8.6.0
    blaze-html-0.9.1.1-A8LR7w4yS96GtRVO7i7OSl bytestring-0.10.8.2
    case-insensitive-1.2.0.11-F6T6GvbsLJXGLQlCHITWZu
    colour-2.3.4-BYzTQyKoQ9LK29pbkBo2SY containers-0.6.0.1
    directory-1.3.3.0 filepath-1.4.2.1
    hxt-9.3.1.16-KGFpujsr1gF9i7MtYNq3HM mtl-2.2.2
    regex-pcre-0.94.4-6OiTOSawdaJqgEwlhRSRS
    safe-0.3.17-43oyx4B630gDZMbTh3Ttji
    skylighting-core-0.7.7-4fEAKVDBpx26AsLTtw5o3K text-1.2.3.1
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
haddock-interfaces: /usr/share/doc/haskell-skylighting/html/skylighting.haddock
haddock-html: /usr/share/doc/haskell-skylighting/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-skylighting-0.7.7-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-skylighting.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: skylighting
version: 0.7.7
id: skylighting-0.7.7-FQboPfcH4jyCr0BJ8xdHGz
key: skylighting-0.7.7-FQboPfcH4jyCr0BJ8xdHGz
license: GPL-2.0-only
copyright: (C) 2016 John MacFarlane
maintainer: jgm@berkeley.edu
author: John MacFarlane
homepage: https://github.com/jgm/skylighting
synopsis: syntax highlighting library
description:
    Skylighting is a syntax highlighting library with
    support for over one hundred languages.  It derives
    its tokenizers from XML syntax definitions used
    by KDE'\''s KSyntaxHighlighting framework, so any
    syntax supported by that framework can be added.
    An optional command-line program is provided.
    Skylighting is intended to be the successor to
    highlighting-kate.
    This package provides generated syntax modules
    based on the KDE XML definitions provided by the
    @skylighting-core@ package. As a result this
    package is licensed under the GPL.
category: Text
abi: c665841ff3926c61db7363b891d9236a
exposed: True
exposed-modules:
    Skylighting,
    Skylighting.Core from skylighting-core-0.7.7-8vupnZDIiY5Imwiwkvb2F3:Skylighting.Core,
    Skylighting.Format.ANSI from skylighting-core-0.7.7-8vupnZDIiY5Imwiwkvb2F3:Skylighting.Format.ANSI,
    Skylighting.Format.HTML from skylighting-core-0.7.7-8vupnZDIiY5Imwiwkvb2F3:Skylighting.Format.HTML,
    Skylighting.Format.LaTeX from skylighting-core-0.7.7-8vupnZDIiY5Imwiwkvb2F3:Skylighting.Format.LaTeX,
    Skylighting.Parser from skylighting-core-0.7.7-8vupnZDIiY5Imwiwkvb2F3:Skylighting.Parser,
    Skylighting.Regex from skylighting-core-0.7.7-8vupnZDIiY5Imwiwkvb2F3:Skylighting.Regex,
    Skylighting.Styles from skylighting-core-0.7.7-8vupnZDIiY5Imwiwkvb2F3:Skylighting.Styles,
    Skylighting.Syntax,
    Skylighting.Tokenizer from skylighting-core-0.7.7-8vupnZDIiY5Imwiwkvb2F3:Skylighting.Tokenizer,
    Skylighting.Types from skylighting-core-0.7.7-8vupnZDIiY5Imwiwkvb2F3:Skylighting.Types
hidden-modules: Skylighting.Syntax.Abc
                Skylighting.Syntax.Actionscript Skylighting.Syntax.Ada
                Skylighting.Syntax.Agda Skylighting.Syntax.Alert
                Skylighting.Syntax.AlertIndent Skylighting.Syntax.Apache
                Skylighting.Syntax.Asn1 Skylighting.Syntax.Asp
                Skylighting.Syntax.Ats Skylighting.Syntax.Awk
                Skylighting.Syntax.Bash Skylighting.Syntax.Bibtex
                Skylighting.Syntax.Boo Skylighting.Syntax.C
                Skylighting.Syntax.Changelog Skylighting.Syntax.Clojure
                Skylighting.Syntax.Cmake Skylighting.Syntax.Coffee
                Skylighting.Syntax.Coldfusion Skylighting.Syntax.Commonlisp
                Skylighting.Syntax.Cpp Skylighting.Syntax.Cs Skylighting.Syntax.Css
                Skylighting.Syntax.Curry Skylighting.Syntax.D
                Skylighting.Syntax.Default Skylighting.Syntax.Diff
                Skylighting.Syntax.Djangotemplate Skylighting.Syntax.Dockerfile
                Skylighting.Syntax.Dot Skylighting.Syntax.Doxygen
                Skylighting.Syntax.Doxygenlua Skylighting.Syntax.Dtd
                Skylighting.Syntax.Eiffel Skylighting.Syntax.Elixir
                Skylighting.Syntax.Email Skylighting.Syntax.Erlang
                Skylighting.Syntax.Fasm Skylighting.Syntax.Fortran
                Skylighting.Syntax.Fsharp Skylighting.Syntax.Gcc
                Skylighting.Syntax.Glsl Skylighting.Syntax.Gnuassembler
                Skylighting.Syntax.Go Skylighting.Syntax.Hamlet
                Skylighting.Syntax.Haskell Skylighting.Syntax.Haxe
                Skylighting.Syntax.Html Skylighting.Syntax.Idris
                Skylighting.Syntax.Ini Skylighting.Syntax.Isocpp
                Skylighting.Syntax.J Skylighting.Syntax.Java
                Skylighting.Syntax.Javadoc Skylighting.Syntax.Javascript
                Skylighting.Syntax.Json Skylighting.Syntax.Jsp
                Skylighting.Syntax.Julia Skylighting.Syntax.Kotlin
                Skylighting.Syntax.Latex Skylighting.Syntax.Lex
                Skylighting.Syntax.Lilypond Skylighting.Syntax.LiterateCurry
                Skylighting.Syntax.LiterateHaskell Skylighting.Syntax.Llvm
                Skylighting.Syntax.Lua Skylighting.Syntax.M4
                Skylighting.Syntax.Makefile Skylighting.Syntax.Mandoc
                Skylighting.Syntax.Markdown Skylighting.Syntax.Mathematica
                Skylighting.Syntax.Matlab Skylighting.Syntax.Maxima
                Skylighting.Syntax.Mediawiki Skylighting.Syntax.Metafont
                Skylighting.Syntax.Mips Skylighting.Syntax.Modelines
                Skylighting.Syntax.Modula2 Skylighting.Syntax.Modula3
                Skylighting.Syntax.Monobasic Skylighting.Syntax.Nasm
                Skylighting.Syntax.Noweb Skylighting.Syntax.Objectivec
                Skylighting.Syntax.Objectivecpp Skylighting.Syntax.Ocaml
                Skylighting.Syntax.Octave Skylighting.Syntax.Opencl
                Skylighting.Syntax.Pascal Skylighting.Syntax.Perl
                Skylighting.Syntax.Php Skylighting.Syntax.Pike
                Skylighting.Syntax.Postscript Skylighting.Syntax.Povray
                Skylighting.Syntax.Powershell Skylighting.Syntax.Prolog
                Skylighting.Syntax.Protobuf Skylighting.Syntax.Pure
                Skylighting.Syntax.Purebasic Skylighting.Syntax.Python
                Skylighting.Syntax.R Skylighting.Syntax.Relaxng
                Skylighting.Syntax.Relaxngcompact Skylighting.Syntax.Rest
                Skylighting.Syntax.Rhtml Skylighting.Syntax.Roff
                Skylighting.Syntax.Ruby Skylighting.Syntax.Rust
                Skylighting.Syntax.Scala Skylighting.Syntax.Scheme
                Skylighting.Syntax.Sci Skylighting.Syntax.Sed
                Skylighting.Syntax.Sgml Skylighting.Syntax.Sml
                Skylighting.Syntax.SqlMysql Skylighting.Syntax.SqlPostgresql
                Skylighting.Syntax.Sql Skylighting.Syntax.Tcl
                Skylighting.Syntax.Tcsh Skylighting.Syntax.Texinfo
                Skylighting.Syntax.Typescript Skylighting.Syntax.Verilog
                Skylighting.Syntax.Vhdl Skylighting.Syntax.Xml
                Skylighting.Syntax.Xorg Skylighting.Syntax.Xslt
                Skylighting.Syntax.Xul Skylighting.Syntax.Yacc
                Skylighting.Syntax.Yaml Skylighting.Syntax.Zsh
import-dirs: /usr/lib/ghc-8.6.4/site-local/skylighting-0.7.7
library-dirs: /usr/lib/ghc-8.6.4/site-local/skylighting-0.7.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/skylighting-0.7.7
hs-libraries: HSskylighting-0.7.7-FQboPfcH4jyCr0BJ8xdHGz
depends:
    aeson-1.4.2.0-QHLwhPMHVB663aXnGqoMq
    ansi-terminal-0.8.2-8WQDEUM7Kz3DSmwgHomKFP
    attoparsec-0.13.2.2-6cOh3sci63HJyadcbPhvpT base-4.12.0.0
    base64-bytestring-1.0.0.2-EJ1mkGsqs004EmS9lh2uZC binary-0.8.6.0
    blaze-html-0.9.1.1-A8LR7w4yS96GtRVO7i7OSl bytestring-0.10.8.2
    case-insensitive-1.2.0.11-F6T6GvbsLJXGLQlCHITWZu
    colour-2.3.4-BYzTQyKoQ9LK29pbkBo2SY containers-0.6.0.1
    directory-1.3.3.0 filepath-1.4.2.1
    hxt-9.3.1.16-KGFpujsr1gF9i7MtYNq3HM mtl-2.2.2
    regex-pcre-0.94.4-6OiTOSawdaJqgEwlhRSRS
    safe-0.3.17-43oyx4B630gDZMbTh3Ttji
    skylighting-core-0.7.7-8vupnZDIiY5Imwiwkvb2F3 text-1.2.3.1
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
haddock-interfaces: /usr/share/doc/haskell-skylighting/html/skylighting.haddock
haddock-html: /usr/share/doc/haskell-skylighting/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
